==> qmmp-0.8.5.tar.bz2: qmmp-0.8.5/src/plugins/Input/flac/translations/flac_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Plugin</source>
        <translation>Wtyczka FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="62"/>
        <source>FLAC Files</source>
        <translation>Pliki FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="200"/>
        <source>About FLAC Audio Plugin</source>
        <translation>O wtyczce FLAC Audio</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="201"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Wtyczka FLAC Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp-0.9.10.tar.bz2: qmmp-0.9.10/src/plugins/Input/flac/translations/flac_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="59"/>
        <source>FLAC Plugin</source>
        <translation>Wtyczka FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="61"/>
        <source>FLAC Files</source>
        <translation>Pliki FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="202"/>
        <source>About FLAC Audio Plugin</source>
        <translation>O wtyczce FLAC Audio</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="203"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Wtyczka FLAC Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="204"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="94"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="95"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="95"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="96"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="96"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
